Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(489)

Unified Diff: content/browser/download/download_file.h

Issue 10696043: Shifted DownloadFile to exporting DownloadInterruptReasons. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Sync'd to TOT. Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/download/download_browsertest.cc ('k') | content/browser/download/download_file_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/download/download_file.h
diff --git a/content/browser/download/download_file.h b/content/browser/download/download_file.h
index ef6e64ea2ffbc1cc3ca561955cf8f2042c98a1af..c0b4d5aaf7280e6fe40cc729e3e5b841e6b38cec 100644
--- a/content/browser/download/download_file.h
+++ b/content/browser/download/download_file.h
@@ -12,7 +12,7 @@
#include "base/file_path.h"
#include "content/common/content_export.h"
#include "content/public/browser/download_id.h"
-#include "net/base/net_errors.h"
+#include "content/public/browser/download_interrupt_reasons.h"
namespace content {
@@ -27,12 +27,13 @@ class CONTENT_EXPORT DownloadFile {
virtual ~DownloadFile() {}
// If calculate_hash is true, sha256 hash will be calculated.
- // Returns net::OK on success, or a network error code on failure.
- virtual net::Error Initialize() = 0;
+ // Returns DOWNLOAD_INTERRUPT_REASON_NONE on success, or a network
+ // error code on failure.
+ virtual DownloadInterruptReason Initialize() = 0;
// Rename the download file.
// Returns net::OK on success, or a network error code on failure.
- virtual net::Error Rename(const FilePath& full_path) = 0;
+ virtual DownloadInterruptReason Rename(const FilePath& full_path) = 0;
// Detach the file so it is not deleted on destruction.
virtual void Detach() = 0;
« no previous file with comments | « chrome/browser/download/download_browsertest.cc ('k') | content/browser/download/download_file_impl.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698